@@ -429,17 +429,25 @@ showed_message_cb (GtrTab * tab,
   GtkTextView *view;
   GtrContextPanel *panel;
   GtkTextMark *path_start, *path_end;
+  GtkTextTag *bold;
 
   panel = gtr_tab_get_context_panel (tab);
   view = gtr_context_panel_get_context_text_view (panel);
 
   buffer = gtk_text_view_get_buffer (view);
 
-  gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
+  gtk_text_buffer_get_end_iter (buffer, &iter);
+
+  /* Create the bold tag for header */
+  bold = gtk_text_buffer_create_tag (buffer, NULL, "weight", PANGO_WEIGHT_BOLD,
+                                     "weight-set", TRUE, NULL);
 
   path_start = gtk_text_buffer_create_mark (buffer,
                                             "path_start", &iter, TRUE);
-  gtk_text_buffer_insert (buffer, &iter, _("Paths:\n"), -1);
+
+  gtk_text_buffer_insert (buffer, &iter, "\n", 1);
+  gtk_text_buffer_insert_with_tags (buffer, &iter, _("Paths:"), -1, bold, NULL);
+  gtk_text_buffer_insert (buffer, &iter, "\n", 1);
 
   filename = gtr_msg_get_filename (msg, i);
   while (filename)
@@ -512,6 +520,18 @@ message_edition_finished_cb (GtrTab * tab,
   delete_text_and_tags (tab, plugin);
 }
 
+static void
+on_context_panel_reloaded (GtrContextPanel         *panel,
+                           GtrMsg                  *msg,
+                           GtrSourceCodeViewPlugin *plugin)
+{
+  GtrTab *tab;
+
+  tab = gtr_window_get_active_tab (plugin->priv->window);
+
+  showed_message_cb (tab, msg, plugin);
+}
+
 static void
 page_added_cb (GtkNotebook * notebook,
                GtkWidget * child,
@@ -535,6 +555,8 @@ page_added_cb (GtkNotebook * notebook,
                     G_CALLBACK (motion_notify_event), NULL);
   g_signal_connect (view, "visibility-notify-event",
                     G_CALLBACK (visibility_notify_event), NULL);
+  g_signal_connect (panel, "reloaded",
+                    G_CALLBACK (on_context_panel_reloaded), plugin);
 }
 
 static void
